@@ -43,7 +43,8 @@ enum php_xml_option {
 	PHP_XML_OPTION_CASE_FOLDING = 1,
 	PHP_XML_OPTION_TARGET_ENCODING,
 	PHP_XML_OPTION_SKIP_TAGSTART,
-	PHP_XML_OPTION_SKIP_WHITE
+	PHP_XML_OPTION_SKIP_WHITE,
+	PHP_XML_OPTION_PARSE_HUGE,
 };
 
 #ifdef LIBXML_EXPAT_COMPAT
